@@ -1,10 +1,10 @@
 package Dist::Zilla::Plugin::Substitute;
 {
-  $Dist::Zilla::Plugin::Substitute::VERSION = '0.002';
+  $Dist::Zilla::Plugin::Substitute::VERSION = '0.003';
 }
 
 use Moose;
-use MooseX::Types -declare => [ 'CodeLiteral' ];
+use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose qw/ArrayRef CodeRef/;
 
 with qw/Dist::Zilla::Role::FileMunger/;
@@ -15,18 +15,27 @@ has finders => (
 	default => sub { [ qw/:InstallModules :ExecFiles/ ] },
 );
 
-subtype CodeLiteral, as CodeRef;
-coerce CodeLiteral, from ArrayRef, via { eval sprintf "sub { %s } ", join "\n", @{ $_ } };
+my $codeliteral = subtype as CodeRef;
+coerce $codeliteral, from ArrayRef, via { eval sprintf "sub { %s } ", join "\n", @{ $_ } };
 
 has code => (
 	is       => 'ro',
-	isa      => CodeLiteral,
+	isa      => $codeliteral,
 	coerce   => 1,
 	required => 1,
 );
+has filename_code => (
+	is       => 'ro',
+	isa      => $codeliteral,
+	coerce   => 1,
+	predicate => '_has_filename_code',
+);
 
 sub mvp_multivalue_args {
-	return qw/finders code/;
+	return qw/finders code filename_code/;
+}
+sub mvp_aliases {
+	return { content_code => 'code' };
 }
 
 sub files {
@@ -48,6 +57,14 @@ sub munge_file {
 	my $code = $self->code;
 	$code->() for @content;
 	$file->content(join "\n", @content);
+
+	if ($self->_has_filename_code) {
+		my $filename = $file->name;
+		my $filename_code = $self->filename_code;
+		$filename_code->() for $filename;
+		$file->name($filename);
+	}
+
 	return;
 }
 
@@ -65,13 +82,14 @@ Dist::Zilla::Plugin::Substitute - Substitutions for files in dzil
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
  [Substitute]
  finder = :ExecFiles
  code = s/Foo/Bar/g
+ filename_code = s/foo\.pl/bar.pl/
 
 =head1 DESCRIPTION
 
@@ -79,14 +97,21 @@ This module performs substitutions on files in Dist::Zilla.
 
 =head1 ATTRIBUTES
 
-=head2 code
+=head2 code (or content_code)
 
-An array-ref of lines of code. This is converted into a sub that's called for each line, with C<$_> containing that line. Alternatively, it may be a sub-ref if passed from for example a pluginbundle. Mandatory.
+An arrayref of lines of code. This is converted into a sub that's called for each line, with C<$_> containing that line. Alternatively, it may be a subref if passed from for example a pluginbundle. Mandatory.
+
+=head2 filename_code
+
+Like C<content_code> but the resulting sub is called for the filename.
+Optional.
 
 =head2 finders
 
 The finders to use for the substitutions. Defaults to C<:InstallModules, :ExecFiles>.
 
+# vi:noet:sts=2:sw=2:ts=2
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
